@@ -311,31 +311,54 @@ class QiDataController:
         :param instrument_ids:
         :return:
         """
-        begin_date = datetime.datetime(begin_date.year, begin_date.month, begin_date.day)
-        end_date = datetime.datetime(end_date.year, end_date.month, end_date.day)
-        begin_trading_date = TradingDayHelper.get_first_trading_day(begin_date)
-        end_trading_date = TradingDayHelper.get_last_trading_day(end_date)
-        lst_trading_days = TradingDayHelper.get_trading_days(begin_trading_date, end_trading_date)
-        bar_provider = BarProvider()
-        bar_provider.create_bar_provider_by_date(self.instrument_manager, instrument_id, begin_trading_date, end_trading_date, interval,
-                                                 bar_type, *instrument_ids)
-        if bar_type == EnumBarType.second:
-            for trading_day in lst_trading_days:
-                tick_series = self.__load_history_tick_series(market, instrument_id, trading_day)
-                for tick in tick_series:
-                    bar_provider.add_tick(tick)
-        elif (bar_type == EnumBarType.minute) | (bar_type == EnumBarType.hour):
-            bar_series_min = self.load_min_bar_series(market, instrument_id, begin_trading_date, end_trading_date)
-            for bar in bar_series_min:
-                bar_provider.add_bar(bar)
-        elif bar_type == EnumBarType.day:
-            bar_series_day = self.load_day_bar_series(market, instrument_id, begin_trading_date, end_trading_date)
-            for bar in bar_series_day:
-                bar_provider.add_bar(bar)
-        else:
-            raise Exception("不支持的k线:" + str(bar_type))
+        if market == EnumMarket.期货:
+            begin_date = datetime.datetime(begin_date.year, begin_date.month, begin_date.day)
+            end_date = datetime.datetime(end_date.year, end_date.month, end_date.day)
+            begin_trading_date = TradingDayHelper.get_first_trading_day(begin_date)
+            end_trading_date = TradingDayHelper.get_last_trading_day(end_date)
+            lst_trading_days = TradingDayHelper.get_trading_days(begin_trading_date, end_trading_date)
+            bar_provider = BarProvider()
+            bar_provider.create_bar_provider_by_date(self.instrument_manager, instrument_id, begin_trading_date, end_trading_date, interval,
+                                                     bar_type, *instrument_ids)
+            if bar_type == EnumBarType.second:
+                for trading_day in lst_trading_days:
+                    tick_series = self.__load_history_tick_series(market, instrument_id, trading_day)
+                    for tick in tick_series:
+                        bar_provider.add_tick(tick)
+            elif (bar_type == EnumBarType.minute) | (bar_type == EnumBarType.hour):
+                bar_series_min = self.load_min_bar_series(market, instrument_id, begin_trading_date, end_trading_date)
+                for bar in bar_series_min:
+                    bar_provider.add_bar(bar)
+            elif bar_type == EnumBarType.day:
+                bar_series_day = self.load_day_bar_series(market, instrument_id, begin_trading_date, end_trading_date)
+                for bar in bar_series_day:
+                    bar_provider.add_bar(bar)
+            else:
+                raise Exception("不支持的k线:" + str(bar_type))
 
-        return bar_provider.bar_series
+            return bar_provider.bar_series
+        elif market == EnumMarket.数字货币:
+            bar_provider = BarProvider()
+            bar_provider.create_bar_provider_by_date_24h(begin_date, end_date, interval, bar_type)
+            if bar_type == EnumBarType.second:
+                trading_day = begin_date
+                while trading_day <= end_date:
+                    tick_series = self.__load_history_tick_series(market, instrument_id, trading_day)
+                    for tick in tick_series:
+                        bar_provider.add_tick(tick)
+                    trading_day = trading_day + datetime.timedelta(days=1)
+            elif (bar_type == EnumBarType.minute) | (bar_type == EnumBarType.hour):
+                bar_series_min = self.load_min_bar_series(market, instrument_id, begin_date, end_date)
+                for bar in bar_series_min:
+                    bar_provider.add_bar(bar)
+            elif bar_type == EnumBarType.day:
+                bar_series_day = self.load_day_bar_series(market, instrument_id, begin_date, end_date)
+                for bar in bar_series_day:
+                    bar_provider.add_bar(bar)
+            else:
+                raise Exception("不支持的k线:" + str(bar_type))
+
+            return bar_provider.bar_series
 
     def load_bar_series_by_date_time(self, market, instrument_id, interval, bar_type, begin_time, end_time, *instrument_ids):
         """
@@ -349,29 +372,32 @@ class QiDataController:
         :param instrument_ids:
         :return:
         """
-        begin_trading_date = YfTimeHelper.get_trading_day(begin_time)
-        end_trading_date = YfTimeHelper.get_trading_day(end_time)
-        lst_trading_days = TradingDayHelper.get_trading_days(begin_trading_date, end_trading_date)
-        bar_provider = BarProvider()
-        bar_provider.create_bar_provider_by_date_time(self.instrument_manager, instrument_id, begin_time, end_time, interval, bar_type,
-                                                      *instrument_ids)
-        if bar_type == EnumBarType.second:
-            for trading_day in lst_trading_days:
-                tick_series = self.__load_history_tick_series(market, instrument_id, trading_day)
-                for tick in tick_series:
-                    bar_provider.add_tick(tick)
-        elif (bar_type == EnumBarType.minute) | (bar_type == EnumBarType.hour):
-            bar_series_min = self.load_min_bar_series(market, instrument_id, begin_trading_date, end_trading_date)
-            for bar in bar_series_min:
-                bar_provider.add_bar(bar)
-        elif bar_type == EnumBarType.day:
-            bar_series_day = self.load_day_bar_series(market, instrument_id, begin_trading_date, end_trading_date)
-            for bar in bar_series_day:
-                bar_provider.add_bar(bar)
-        else:
-            raise Exception("不支持的k线:" + str(bar_type))
+        if market == EnumMarket.期货:
+            begin_trading_date = YfTimeHelper.get_trading_day(begin_time)
+            end_trading_date = YfTimeHelper.get_trading_day(end_time)
+            lst_trading_days = TradingDayHelper.get_trading_days(begin_trading_date, end_trading_date)
+            bar_provider = BarProvider()
+            bar_provider.create_bar_provider_by_date_time(self.instrument_manager, instrument_id, begin_time, end_time, interval, bar_type,
+                                                          *instrument_ids)
+            if bar_type == EnumBarType.second:
+                for trading_day in lst_trading_days:
+                    tick_series = self.__load_history_tick_series(market, instrument_id, trading_day)
+                    for tick in tick_series:
+                        bar_provider.add_tick(tick)
+            elif (bar_type == EnumBarType.minute) | (bar_type == EnumBarType.hour):
+                bar_series_min = self.load_min_bar_series(market, instrument_id, begin_trading_date, end_trading_date)
+                for bar in bar_series_min:
+                    bar_provider.add_bar(bar)
+            elif bar_type == EnumBarType.day:
+                bar_series_day = self.load_day_bar_series(market, instrument_id, begin_trading_date, end_trading_date)
+                for bar in bar_series_day:
+                    bar_provider.add_bar(bar)
+            else:
+                raise Exception("不支持的k线:" + str(bar_type))
 
-        return bar_provider.bar_series
+            return bar_provider.bar_series
+        else:
+            raise Exception("不支持的市场:" + str(market))
 
     def load_bar_series_by_length(self, market, instrument_id, interval, bar_type, max_length, end_date, *instrument_ids):
         """
@@ -386,88 +412,91 @@ class QiDataController:
         :return:
         """
         # 这里为了提升取数据的速度,根据时间预计算根数,不足再补
-        end_trading_date = TradingDayHelper.get_last_trading_day(end_date)
-        lst_date_time_slices_one_day = BaseBarHelper.create_one_day_date_time_slice(
-            self.instrument_manager, instrument_id, end_trading_date, interval, bar_type, *instrument_ids)
-        if len(lst_date_time_slices_one_day) > 0:
-            n_one_day_count = len(lst_date_time_slices_one_day)
-        else:
-            n_one_day_count = 1
+        if market == EnumMarket.期货:
+            end_trading_date = TradingDayHelper.get_last_trading_day(end_date)
+            lst_date_time_slices_one_day = BaseBarHelper.create_one_day_date_time_slice(
+                self.instrument_manager, instrument_id, end_trading_date, interval, bar_type, *instrument_ids)
+            if len(lst_date_time_slices_one_day) > 0:
+                n_one_day_count = len(lst_date_time_slices_one_day)
+            else:
+                n_one_day_count = 1
 
-        n_trading_days = int(math.ceil(max_length * 1.0 / n_one_day_count))
-        if bar_type == EnumBarType.day:
-            n_trading_days = n_trading_days * interval
-        else:
-            n_trading_days = n_trading_days
+            n_trading_days = int(math.ceil(max_length * 1.0 / n_one_day_count))
+            if bar_type == EnumBarType.day:
+                n_trading_days = n_trading_days * interval
+            else:
+                n_trading_days = n_trading_days
 
-        begin_trading_date = TradingDayHelper.get_pre_trading_day(end_trading_date, n_trading_days - 1)
-        lst_trading_days = TradingDayHelper.get_trading_days(begin_trading_date, end_trading_date)
-        bar_provider = BarProvider()
-        bar_provider.create_bar_provider_by_date(
-            self.instrument_manager, instrument_id, begin_trading_date, end_trading_date, interval, bar_type, *instrument_ids)
-        if bar_provider.bar_type == EnumBarType.second:
-            for trading_day in lst_trading_days:
-                tick_series = self.__load_history_tick_series(market, instrument_id, trading_day)
-                for tick in tick_series:
-                    bar_provider.add_tick(tick)
-        elif (bar_provider.bar_type == EnumBarType.minute) | (bar_provider.bar_type == EnumBarType.hour):
-            bar_series_min = self.load_min_bar_series(market, instrument_id, begin_trading_date, end_trading_date)
-            for bar in bar_series_min:
-                bar_provider.add_bar(bar)
-        elif bar_provider.bar_type == EnumBarType.day:
-            bar_series_day = self.load_day_bar_series(market, instrument_id, begin_trading_date, end_trading_date)
-            for bar in bar_series_day:
-                bar_provider.add_bar(bar)
-        else:
-            raise Exception("不支持的k线:" + str(bar_type))
-
-        bar_series = bar_provider.bar_series
-        if len(bar_provider.bar_series) < max_length:
-            trading_date = begin_trading_date
-            count = 0
-            while count < 5:
-                count += 1
-                trading_date = TradingDayHelper.get_pre_trading_day(trading_date)
-                if bar_provider.bar_type == EnumBarType.second:
-                    bar_provider = BarProvider()
-                    bar_provider.create_bar_provider_by_trading_date(self.instrument_manager, instrument_id, trading_date, interval, bar_type, *instrument_ids)
-                    tick_series = self.__load_history_tick_series(market, instrument_id, trading_date)
+            begin_trading_date = TradingDayHelper.get_pre_trading_day(end_trading_date, n_trading_days - 1)
+            lst_trading_days = TradingDayHelper.get_trading_days(begin_trading_date, end_trading_date)
+            bar_provider = BarProvider()
+            bar_provider.create_bar_provider_by_date(
+                self.instrument_manager, instrument_id, begin_trading_date, end_trading_date, interval, bar_type, *instrument_ids)
+            if bar_provider.bar_type == EnumBarType.second:
+                for trading_day in lst_trading_days:
+                    tick_series = self.__load_history_tick_series(market, instrument_id, trading_day)
                     for tick in tick_series:
                         bar_provider.add_tick(tick)
-                elif (bar_provider.bar_type == EnumBarType.minute) | (bar_provider.bar_type == EnumBarType.hour):
-                    bar_provider = BarProvider()
-                    bar_provider.create_bar_provider_by_trading_date(self.instrument_manager, instrument_id, trading_date, interval, bar_type, *instrument_ids)
-                    bar_series_min = self.load_min_bar_series(market, instrument_id, trading_date)
-                    for bar in bar_series_min:
-                        bar_provider.add_bar(bar)
-                elif bar_provider.bar_type == EnumBarType.day:
-                    begin_date = TradingDayHelper.get_pre_trading_day(trading_date, interval - 1)
-                    bar_provider = BarProvider()
-                    bar_provider.create_bar_provider_by_trading_date(self.instrument_manager, instrument_id, trading_date, interval, bar_type, *instrument_ids)
-                    bar_series_day = self.load_day_bar_series(market, instrument_id, begin_date, end_trading_date)
-                    trading_date = begin_date
-                    for bar in bar_series_day:
-                        bar_provider.add_bar(bar)
-                else:
-                    raise Exception("不支持的k线:" + str(bar_type))
+            elif (bar_provider.bar_type == EnumBarType.minute) | (bar_provider.bar_type == EnumBarType.hour):
+                bar_series_min = self.load_min_bar_series(market, instrument_id, begin_trading_date, end_trading_date)
+                for bar in bar_series_min:
+                    bar_provider.add_bar(bar)
+            elif bar_provider.bar_type == EnumBarType.day:
+                bar_series_day = self.load_day_bar_series(market, instrument_id, begin_trading_date, end_trading_date)
+                for bar in bar_series_day:
+                    bar_provider.add_bar(bar)
+            else:
+                raise Exception("不支持的k线:" + str(bar_type))
 
-                bar_provider.bar_series.extend(bar_series)
-                bar_series = bar_provider.bar_series
+            bar_series = bar_provider.bar_series
+            if len(bar_provider.bar_series) < max_length:
+                trading_date = begin_trading_date
+                count = 0
+                while count < 5:
+                    count += 1
+                    trading_date = TradingDayHelper.get_pre_trading_day(trading_date)
+                    if bar_provider.bar_type == EnumBarType.second:
+                        bar_provider = BarProvider()
+                        bar_provider.create_bar_provider_by_trading_date(self.instrument_manager, instrument_id, trading_date, interval, bar_type, *instrument_ids)
+                        tick_series = self.__load_history_tick_series(market, instrument_id, trading_date)
+                        for tick in tick_series:
+                            bar_provider.add_tick(tick)
+                    elif (bar_provider.bar_type == EnumBarType.minute) | (bar_provider.bar_type == EnumBarType.hour):
+                        bar_provider = BarProvider()
+                        bar_provider.create_bar_provider_by_trading_date(self.instrument_manager, instrument_id, trading_date, interval, bar_type, *instrument_ids)
+                        bar_series_min = self.load_min_bar_series(market, instrument_id, trading_date)
+                        for bar in bar_series_min:
+                            bar_provider.add_bar(bar)
+                    elif bar_provider.bar_type == EnumBarType.day:
+                        begin_date = TradingDayHelper.get_pre_trading_day(trading_date, interval - 1)
+                        bar_provider = BarProvider()
+                        bar_provider.create_bar_provider_by_trading_date(self.instrument_manager, instrument_id, trading_date, interval, bar_type, *instrument_ids)
+                        bar_series_day = self.load_day_bar_series(market, instrument_id, begin_date, end_trading_date)
+                        trading_date = begin_date
+                        for bar in bar_series_day:
+                            bar_provider.add_bar(bar)
+                    else:
+                        raise Exception("不支持的k线:" + str(bar_type))
 
-                if len(bar_series) >= max_length:
-                    break
+                    bar_provider.bar_series.extend(bar_series)
+                    bar_series = bar_provider.bar_series
 
-        bar_provider = BarProvider()
-        next_trading_date = TradingDayHelper.get_next_trading_day(end_trading_date)
-        bar_provider.create_bar_provider_by_trading_date(self.instrument_manager, instrument_id, next_trading_date, interval, bar_type, *instrument_ids)
-        for bar in bar_series:
-            bar_provider.bar_series.append(bar)
+                    if len(bar_series) >= max_length:
+                        break
 
-        remove_length = len(bar_provider.bar_series) - max_length
-        if remove_length > 0:
-            del bar_provider.bar_series[0:remove_length]
+            bar_provider = BarProvider()
+            next_trading_date = TradingDayHelper.get_next_trading_day(end_trading_date)
+            bar_provider.create_bar_provider_by_trading_date(self.instrument_manager, instrument_id, next_trading_date, interval, bar_type, *instrument_ids)
+            for bar in bar_series:
+                bar_provider.bar_series.append(bar)
 
-        return bar_provider.bar_series
+            remove_length = len(bar_provider.bar_series) - max_length
+            if remove_length > 0:
+                del bar_provider.bar_series[0:remove_length]
+
+            return bar_provider.bar_series
+        else:
+            raise Exception("不支持的市场:" + str(market))
 
     def load_night_am_pm_bar_series_by_date(self, market, instrument_id, begin_date, end_date, *instrument_ids):
         """
