@@ -538,7 +538,7 @@ class FutureCache:
             self.lst_order.append(
                 [order.product_code, order.strategy_id, order.trading_date, order.order_time, order.instrument_id, order.order_price,
                  order.direction.chinese_name(), order.open_close.chinese_name(), order.order_volume,
-                 order.order_status.chinese_name()])
+                 order.order_status])
 
         for trade in future_data.trades:
             self.all_trades.append(trade)
